@@ -25,6 +25,8 @@
 Resource::Resource(ToolWindow *toolwindow):
 		BaseResource(toolwindow)
 {
+	report.runCommand=NULL;
+	spoolfile=NULL;
 	report.force_check=False;
 	frame.font=0;
 	label.font=0;
